chemfeat.features package
=========================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   chemfeat.features.calculators

Submodules
----------

chemfeat.features.calculator module
-----------------------------------

.. automodule:: chemfeat.features.calculator
   :members:
   :undoc-members:
   :show-inheritance:

chemfeat.features.manager module
--------------------------------

.. automodule:: chemfeat.features.manager
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: chemfeat.features
   :members:
   :undoc-members:
   :show-inheritance:
